/*
simple I2C receiver to set a servo
expects a value from 0-250 and creates a pulse of 1000-2000 uS from that value
servo on pin 1 is in normal mode, servo on pin 2 is in reverse mode
value        action
0      ...   full left (or right)
125    ...   center
250    ...   full right (or left)
*/

#include <Wire.h>
#include <Servo.h> 

int i2c_address = 33;

int hotend_pin = 5;

int servo1_pin = 9;
int servo2_pin = 10;

Servo servo1;  // create servo object to control servo 1
Servo servo2;  // create servo object to control servo 2
                // a maximum of eight servo objects can be created 

void setup()
{
  Wire.begin(i2c_address);            // join i2c bus with address supplied
  Wire.onReceive(receiveEvent);       // register event
  
  // initialize the digital pin as an output.
  pinMode(hotend_pin, OUTPUT);    
  //analogWrite(hotend_pin, 2); 
  
  // attach the servos to the servo pins
  servo1.attach(servo1_pin);  // attaches the servo pin to the servo object 
  servo2.attach(servo2_pin);  // attaches the servo pin to the servo object 

}

void loop()
{
  delay(100);
}


// function that executes whenever data is received from master
// this function is registered as an event, see setup()
void receiveEvent(int howMany)
{
  byte reading = 0;
  reading = Wire.read();
  servo1.writeMicroseconds(1000+reading*4); 
  servo2.writeMicroseconds(2000-reading*4);
  analogWrite(hotend_pin, reading); 
}
